@@ -3,6 +3,7 @@ use tokio::sync::Mutex;
 use crate::workers::{Signal,SignalData,Pointer};
 use tokio::sync::Notify;
 
+#[derive(Debug,Clone)]
 pub struct QueResponse{
     signal:Arc<Mutex<Signal>>,
     sleeper:Arc<Notify>
@@ -15,7 +16,7 @@ impl QueResponse{
             sleeper:sleeper
         }
     }
-    pub async fn check(&mut self)->bool{
+    pub async fn check(&self)->bool{
         self.sleeper.notified().await;
         if !Signal::check(&self.signal).await{
             return false;
@@ -25,10 +26,17 @@ impl QueResponse{
     }
     pub async fn data(self)->Option<(Vec<u8>,Pointer)>{
         match Signal::get(self.signal).await{
-            SignalData::Value(v)=>{
-                Some(v)
+            Ok(v)=>{
+                match v{
+                    SignalData::Value(v)=>{
+                        Some(v)
+                    },
+                    _=>{None}
+                }
             },
-            _=>{None}
+            Err(_)=>{
+                return None;
+            }
         }
     }
 }
\ No newline at end of file
